
clear

loc path "[---- add path to folder with dataset.dta ----]"
cd "`path'"
set more off
set matsize 1000
use dataset.dta, clear

sort countrynum quarter2
loc vars mincap fcsc rwcons dp mpprr cgrr
foreach v of var `vars' {
	gen exo_`v' = 0	
}

**** Tag exogenous measures

replace exo_cgrr = 1 if country=="Bulgaria" & quarter=="2006Q3"
replace exo_cgrr = 1 if country=="Bulgaria" & quarter=="2007Q1"
replace exo_rwcons = 1 if country=="Czech Republic" & quarter=="2007Q1"
replace exo_rwcons = 1 if country=="Estonia" & quarter=="2008Q1"
replace exo_rwcons = 1 if country=="Hungary" & quarter=="2008Q1"
replace exo_mincap = 1 if country=="Latvia" & quarter=="2004Q4"
replace exo_mincap = 1 if country=="Lithuania" & quarter=="2004Q4"
replace exo_rwcons = 1 if country=="Lithuania" & quarter=="2008Q1"
replace exo_rwcons = 1 if country=="Poland" & quarter=="2008Q1"
replace exo_dp = 1 if country=="Poland" & quarter=="2004Q1" // only one exo_dp observation
replace exo_mincap = 1 if country=="Romania" & quarter=="2007Q1"
replace exo_fcsc = 1 if country=="Romania" & quarter=="2007Q1" // only one exo_fcsc observation
replace exo_rwcons = 1 if country=="Romania" & quarter=="2008Q1"
replace exo_rwcons = 1 if country=="Slovakia" & quarter=="2008Q1"
replace exo_mpprr = 1 if country=="Slovakia" & quarter=="2003Q1"
replace exo_mpprr = 1 if country=="Slovakia" & quarter=="2004Q1"
replace exo_rwcons = 1 if country=="Slovenia" & quarter=="2008Q1"
replace exo_mpprr = 1 if country=="Slovenia" & quarter=="2003Q3"
replace exo_mpprr = 1 if country=="Slovenia" & quarter=="2005Q1"

foreach v of var `vars' {
	gen endo_`v' = 1-exo_`v'	
}

loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc nmpp dl.nz dll.nz

**** REGRESSION FOR TABLE 6

** preliminary regressions

foreach v of var `vars' {
	gen z = `v'
	gen nz = mpp1 + rest -`v'
	gen inter_exo`v' = d.`v' * exo_`v'
	gen inter_endo`v' = d.`v' * endo_`v'
	loc inter_exo l.inter_exo`v' ll.inter_exo`v' 
	loc inter_endo l.inter_endo`v' ll.inter_endo`v'
	quietly xtpmg `depvar' `ar' `controls' `inter_exo' `inter_endo' `basel' `nmpp' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
	est store j`v', title (`v')
	test l.inter_exo`v'+ll.inter_exo`v'=0
	estadd scalar r(p)
	drop z nz
}

loc mincap l.inter_exomincap ll.inter_exomincap l.inter_endomincap ll.inter_endomincap
loc rwcons l.inter_exorwcons ll.inter_exorwcons l.inter_endorwcons ll.inter_endorwcons
loc cgrr l.inter_exocgrr ll.inter_exocgrr l.inter_endocgrr ll.inter_endocgrr
loc mpps ld.mrrtot lld.mrrtot ld.hhsc lld.hhsc //ld.dti lld.dti
gen nmppcore1 = mpp1 + rest - mincap - mrrtot - cgrr - hhsc //- dti
loc nmppcore1 dl.nmppcore1 dll.nmppcore1
gen nmpp1 = mpp1 + rest - mincap - rwcons - mrrtot - cgrr - hhsc //- dti
loc nmpp1 dl.nmpp1 dll.nmpp1

** baseline regression

* for Table 6
quietly xtpmg `depvar' `ar' `controls' `mincap' `cgrr' `mpps' `basel' `nmppcore1' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store basecore1, title (basecore)
test l.inter_exomincap+ll.inter_exomincap=0
estadd scalar mincap = r(p)
test l.inter_exocgrr+ll.inter_exocgrr=0
estadd scalar cgrr = r(p)


* adding rwcons to core set
quietly xtpmg `depvar' `ar' `controls' `mincap' `cgrr' `rwcons' `mpps' `basel' `nmpp1' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store base1, title (base)
test l.inter_exomincap+ll.inter_exomincap=0
estadd scalar mincap = r(p)
test l.inter_exocgrr+ll.inter_exocgrr=0
estadd scalar cgrr = r(p)
test l.inter_exorwcons+ll.inter_exorwcons=0
estadd scalar rwcons = r(p)


**** REGRESSIONS FOR TABLE 7

*** preliminary regressions

gen eboom = .
gen nboom = .
loc vars mincap cap cgrcap hhsc fcsc lsctot rwmol rwmolfc rwmoltot rwcons rwconsfc rwconstot rw rwfc rwtot rwcc rwtot2 gp dp dpfc dptot ///
	mpprr rrtot mrrtot fclr cgrr lr ltv ltvfc ltvtot dti dtifc dtitot elig otherfc
	
foreach v of var `vars' {
	gen `v'ease = 0	
	gen z = `v'
	replace `v'ease = 1 if d.z<0
	gen nz = mpp1 + rest -`v'
	replace eboom = `v'ease*boom
	replace nboom = 1 - eboom
	gen inter_boom`v' = d.`v'*eboom
	gen inter_nboom`v' = d.`v'*nboom
	loc inter_boom l.inter_boom`v' ll.inter_boom`v'
	loc inter_nboom l.inter_nboom`v' ll.inter_nboom`v'
	quietly xtpmg `depvar' `ar' `controls' `inter_boom' `inter_nboom' `basel' `nmpp' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
	est store i`v', title (`v')
	test l.inter_boom`v'+ll.inter_boom`v'=0
	estadd scalar r(p)
	drop z nz
}

*** baseline regressions


gen nmppcore2 = mpp1 + rest - mincap - hhsc - mrrtot - cgrr 
loc nmppcore2 dl.nmppcore2 dll.nmppcore2

loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop

loc mincap l.inter_boommincap ll.inter_boommincap l.inter_nboommincap ll.inter_nboommincap
loc hhsc l.inter_boomhhsc ll.inter_boomhhsc l.inter_nboomhhsc ll.inter_nboomhhsc
loc mrrtot l.inter_boommrrtot ll.inter_boommrrtot l.inter_nboommrrtot ll.inter_nboommrrtot
loc cgrr l.inter_boomcgrr ll.inter_boomcgrr l.inter_nboomcgrr ll.inter_nboomcgrr


quietly xtpmg `depvar' `ar' `controls' `mincap' `mrrtot' `cgrr' `hhsc' `basel' `nmppcore2' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store basecore2, title (base)
test l.inter_boommincap+ll.inter_boommincap=0
estadd scalar mincap = r(p)
test l.inter_boommrrtot+ll.inter_boommrrtot=0
estadd scalar mrrtot = r(p)
test l.inter_boomcgrr+ll.inter_boomcgrr=0
estadd scalar cgrr = r(p)
test l.inter_boomhhsc+ll.inter_boomhhsc=0
estadd scalar hhsc = r(p)


**** OUTPUT TABLES

set more off
loc drop *td* *nz* *_cons* *nhp* *ec* *pcapgdp* *rate* *ukr* *work* /*basel*/
log using exogeneity-analysis, replace

*** exogenous measures

estout jmincap jfcsc jrwcons jdp jmpprr jcgrr, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("EXOGENOUS MEASURES")
loc drop *td* *nmpp* *_cons* *nhp* *ec* *pcapgdp* *rate* *ukr* *work*
* Table 6
estout basecore1 base1, cells(b(star fmt(2)) p(par fmt(2))) stats(mincap cgrr rwcons) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("EXOGENOUS MEASURES") // First column is Table 6
		
*** easing during the boom

** preliminary regressions

loc drop *td* *nz* *_cons* *nhp* *ec* *pcapgdp* *rate* *ukr* *work*
* capital measures
estout imincap icap icgrcap ihhsc ifcsc ilsctot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("CAPITAL MEASURES")
* risk weights (separate)
estout irwmol irwmolfc irwmoltot irwcons irwconsfc irwconstot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("RISK WEIGHTS 1")
* risk weights (aggregate)
estout irw irwfc irwtot irwcc irwtot2, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("RISK WEIGHTS 2")
* dynamic provisioning
estout igp idp idpfc idptot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("DYNAMIC PROVISIONING")
* liquidity measures
estout impprr irrtot ilr ifclr imrrtot icgrr, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("LIQUIDITY MEASURES")
* eligibility
estout iltv iltvfc iltvtot idti idtifc idtitot ielig, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("ELIGIBILITY MEASURES")
* other fc
estout iotherfc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("other FC")

** baseline regression

* Table 7
loc drop *td* *nmpp* *_cons* *nhp* *ec* *pcapgdp* *rate* *ukr* *work* /*basel*/
estout basecore2, cells(b(star fmt(2)) p(par fmt(2))) stats(mincap mrrtot cgrr hhsc rbase) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.inter "mpp*ease*boom t-1" L2.inter "mpp*ease*boom t-2") prehead("EXOGENOUS MEASURES") 

log close		
	
