
clear
loc path "[---- add path to folder with dataset.dta ----]"
cd "`path'"
set more off, permanently
set matsize 1000
use dataset

*---------------------------------------------------------------------------------------------*
*            BASELINE REGRESSION
*---------------------------------------------------------------------------------------------*
sort countrynum quarter2
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
gen nz = mpp1 + rest - mincap - mrrtot - cgrr - hhsc
loc mpps ld.mincap lld.mincap ld.hhsc lld.hhsc ld.mrrtot lld.mrrtot ld.cgrr lld.cgrr
loc nz ld.nz lld.nz
loc level l.lnhpi l.lnpcapgdpsa
quietly xtreg d.lnhpi `level' `ar' `controls' `mpps' `nz' td* ukr*, fe vce(robust)
est store xtreg, title (xtreg)
drop nz

*---------------------------------------------------------------------------------------------*
*            DYNAMIC MULTIPLIERS
*---------------------------------------------------------------------------------------------*
foreach v of var mincap hhsc mrrtot cgrr {

* coefficients
loc a1 _b[DL.lnhpi]
loc a2 _b[DLL.lnhpi]
loc b1 _b[DL.`v']
loc b2 _b[DLL.`v']
loc g  _b[L.lnhpi]	

** t=1
di "level1 and change1"
nlcom _b[LD.`v']
loc level1`v' 	_b[LD.`v']
loc change1`v' 	_b[LD.`v']

** t=2
di "level2 `v'"
nlcom 			(1+`g')*`level1`v'' + `a1'*`change1`v'' + `b2'
loc level2`v'	(1+`g'+`a1')*`level1`v''  + `b2'
loc change2`v'	(`g'+`a1')*`level1`v'' + `b2'

** t=3
di "level3 `v'"
nlcom 			(1+`g')*(`level1`v'') + (1+`g'+`a1')*(`change2`v'') + `a2'*(`change1`v'')
loc level3`v' 	(1+`g'+ `a2')*(`level1`v'') + (1+`g'+`a1')*(`change2`v'') 
loc change3`v' 	(`g'+ `a2')*(`level1`v'') + (`g'+`a1')*(`change2`v'') 

** t=4
di "level4 `v'"
nlcom 			(1+`g')*(`level1`v'') + (1+`g'+`a1')*(`change3`v'') + (1+`g'+`a2')*(`change2`v'')
loc level4`v'	(1+`g')*(`level1`v'') + (1+`g'+`a1')*(`change3`v'') + (1+`g'+`a2')*(`change2`v'')
loc change4`v'	`g'*(`level1`v'') + (`g'+`a1')*(`change3`v'') + (`g'+`a2')*(`change2`v'')

** t=5
di "level5 `v'"
nlcom 			((1+`g')+(1+`g'+`a1')*`g')*(`level1`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change2`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change3`v'')
loc level5`v'	((1+`g')+(1+`g'+`a1')*`g')*(`level1`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change2`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change3`v'')
loc change5`v'	((1+`g'+`a1')*`g')*(`level1`v'') + (`g'+(`g'+`a1')*(`g'+`a2'))*(`change2`v'') + ((`g'+`a2')+(`g'+`a1')^2)*(`change3`v'')
	
** t=6
di "level6 `v'"
nlcom 			((1+`g')+(1+`g'+`a1')*`g')*(`level2`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change3`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change4`v'')
loc level6`v'	((1+`g')+(1+`g'+`a1')*`g')*(`level2`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change3`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change4`v'')
loc change6`v'	((1+`g'+`a1')*`g')*(`level2`v'') + (`g'+(`g'+`a1')*(`g'+`a2'))*(`change3`v'') + ((`g'+`a2')+(`g'+`a1')^2)*(`change4`v'')

** t=7
di "level7 `v'"
nlcom 			((1+`g')+(1+`g'+`a1')*`g')*(`level3`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change4`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change5`v'')
loc level7`v'	((1+`g')+(1+`g'+`a1')*`g')*(`level3`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change4`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change5`v'')
loc change7`v'	((1+`g'+`a1')*`g')*(`level3`v'') + (`g'+(`g'+`a1')*(`g'+`a2'))*(`change4`v'') + ((`g'+`a2')+(`g'+`a1')^2)*(`change5`v'')

** t=8
di "level8 `v'"
nlcom 			((1+`g')+(1+`g'+`a1')*`g')*(`level4`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change5`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change6`v'')
loc level8`v'	((1+`g')+(1+`g'+`a1')*`g')*(`level4`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change5`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change6`v'')
loc change8`v'	((1+`g'+`a1')*`g')*(`level4`v'') + (`g'+(`g'+`a1')*(`g'+`a2'))*(`change5`v'') + ((`g'+`a2')+(`g'+`a1')^2)*(`change6`v'')
	
** t=9
di "level9 `v'"
nlcom 			((1+`g')+(1+`g'+`a1')*`g')*(`level5`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change6`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change7`v'')
loc level9`v'	((1+`g')+(1+`g'+`a1')*`g')*(`level5`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change6`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change7`v'')
loc change9`v'	((1+`g'+`a1')*`g')*(`level5`v'') + (`g'+(`g'+`a1')*(`g'+`a2'))*(`change6`v'') + ((`g'+`a2')+(`g'+`a1')^2)*(`change7`v'')

** t=10
di "level10 `v'"
nlcom 			((1+`g')+(1+`g'+`a1')*`g')*(`level6`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change7`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change8`v'')
loc level10`v'	((1+`g')+(1+`g'+`a1')*`g')*(`level6`v'') + ((1+`g')+(1+`g'+`a1')*(`g'+`a2'))*(`change7`v'') + ((1+`g'+`a2')+(1+`g'+`a1')*(`g'+`a1'))*(`change8`v'')
loc change10`v'	((1+`g'+`a1')*`g')*(`level6`v'') + (`g'+(`g'+`a1')*(`g'+`a2'))*(`change7`v'') + ((`g'+`a2')+(`g'+`a1')^2)*(`change8`v'')
}	
