

loc path "[---- add path to folder with dataset.dta ----]"
cd "`path'"
set more off, permanently 
set matsize 1000
use dataset, clear

/*		**** SUMMARY STATISTICS 
		loc base lnhpi lncredit_h lnpcapgdpsa domesticrate foreignrate 
		loc cap mincap	cap	cgrcap hhsc	fcsc lsctot
		loc rw rwmol rwmolfc rwmoltot rwcons rwconsfc rwconstot rw rwfc rwtot rwcc rwtot2
		loc dyn gp dp dpfc dptot
		loc liq mpprr rrtot mrrtot lr fclr cgrr
		loc elig ltv ltvfc ltvtot dti dtifc dtitot elig
		loc other otherfc tax other rest 
		set more off
		log using summarystatistics, replace
		foreach v of var `base' `cap' `rw' `dyn' `liq' `elig' `other' {
			sum d.`v' if e(sample)
		}
		sum dlnworkpop if e(sample)
		log close
*/


*---------------------------------------------------------------------------------------------*
*            Regressions - HOUSING PRICES
*---------------------------------------------------------------------------------------------*

**** PRELIMINARY REGRESSIONS

sort countrynum quarter2
loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc level l.lnhpi l.lnpcapgdpsa
loc mpp dl.z dll.z 
loc nmpp dl.nz dll.nz
loc vars mincap cap cgrcap hhsc fcsc lsctot rwmol rwmolfc rwmoltot rwcons rwconsfc rwconstot rw rwfc rwtot rwcc rwtot2 gp dp dpfc dptot ///
	mpprr rrtot mrrtot fclr cgrr lr ltv ltvfc ltvtot dti dtifc dtitot elig otherfc

foreach v of var `vars' {
	gen z = `v'
	gen nz = mpp1 + rest -`v'
	quietly xtpmg `depvar' `ar' `controls' `mpp' `nmpp' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
	est store i`v', title (`v')
	test dl.z+dll.z=0
	estadd scalar r(p)
	drop z nz
}

**** BASELINE REGRESSION

gen nz = mpp1 + rest - mincap - hhsc - mrrtot - cgrr

*xtpmg
loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc mpps ld.mincap lld.mincap ld.hhsc lld.hhsc ld.mrrtot lld.mrrtot ld.cgrr lld.cgrr
loc level l.lnhpi l.lnpcapgdpsa
loc level2 l.lnhpi l.lnpcapgdpsa l.lncredit_h
loc nz ld.nz lld.nz

quietly xtpmg `depvar' `ar' `controls' `mpps' `nz' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store base1, title (base1xtpmg)
test ld.mincap+lld.mincap=0
estadd scalar mincap = r(p)
test ld.mrrtot+lld.mrrtot=0
estadd scalar mrrtot = r(p)
test ld.cgrr+lld.cgrr=0
estadd scalar cgrr = r(p)
test ld.hhsc+lld.hhsc=0
estadd scalar hhsc = r(p)
test ld.nz+lld.nz=0
estadd scalar nz = r(p)

* xtreg
quietly xtreg `depvar' `level' `ar' `controls' `mpps' `nz' td* ukr*, fe vce(robust)
est store base2, title (base3xtreg)

**** OUTPUTTABLES

loc drop *td* *nz* *con* *nhp* *ec* *pcapgdp* *rate* *ukr* *work*
log using outputtables_preliminary-baseline-regs, replace

*** preliminary regressions
** capital measures
estout imincap icap icgrcap ihhsc ifcsc ilsctot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("CAPITAL MEASURES")
** risk weights (separate)
estout irwmol irwmolfc irwmoltot irwcons irwconsfc irwconstot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 1")
** risk weights (aggregate)
estout irw irwfc irwtot irwcc irwtot2, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 2")
** dynamic provisioning
estout igp idp idpfc idptot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("DYNAMIC PROVISIONING")
** liquidity measures
estout impprr irrtot ilr ifclr imrrtot icgrr, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("LIQUIDITY MEASURES")
** eligibility
estout iltv iltvfc iltvtot idti idtifc idtitot ielig, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("ELIGIBILITY MEASURES")
** other fc
estout iotherfc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("other FC")
		
*** baseline regressions
loc drop *td* *con* *ukr*
estout base1, cells(b(star fmt(2)) p(par fmt(2))) stats(r2 r2_a N mincap mrrtot cgrr hhsc nz, fmt(3 3 0 2 2 2 2 2) label(R-sqr adj.R-sqr N)) ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 
estout base2, cells(b(star fmt(2)) p(par fmt(2))) stats(r2 r2_a N, fmt(3 3 0) label(R-sqr adj.R-sqr N)) ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 

log close


*---------------------------------------------------------------------------------------------*
*            Regression - HOUSEHOLD CREDIT
*---------------------------------------------------------------------------------------------*
use dataset, clear
sort countrynum quarter2
loc depvar d.lncredit_h
loc ar dl.lncredit_h dll.lncredit_h
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc level lncredit_h l.lnpcapgdpsa
loc mpps ld.mincap lld.mincap ld.hhsc lld.hhsc ld.mrrtot lld.mrrtot ld.cgrr lld.cgrr
gen nz = mpp1 + rest - mincap - hhsc - mrrtot - cgrr 
loc nz ld.nz lld.nz

**** PLAIN BASELINE REGRESSION

quietly xtpmg `depvar' `ar' `controls' `mpps' `nz' td* ukr*, lr(`level') ec(ec) replace dfe cluster(countrynum)
est store credit, title (credit1)
test ld.mincap+lld.mincap=0
estadd scalar mincap = r(p)
test ld.hhsc+lld.hhsc=0
estadd scalar hhsc = r(p)
test ld.mrrtot+lld.mrrtot=0
estadd scalar mrrtot = r(p)
test ld.cgrr+lld.cgrr=0
estadd scalar cgrr = r(p)

**** OUTPUT TABLE

***baseline regression
loc drop td* *nz* *con* *credit* *pcapgdp* *rate* ec *ukr* *work*
log using outputtables_credit_baseline, replace
estout credit, cells(b(star fmt(2)) p(par fmt(2))) stats(mincap mrrtot cgrr hhsc) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(L.tz "tightMPP t-1" L2.tz "tightMPP t-2" L.ez "easeMPP t-1" L2.ez "easeMPP t-2") prehead("Household Credit")
log close
