
clear
loc path "[---- add path to folder with dataset.dta ----]"
cd "`path'"
set more off
set matsize 1000


*---------------------------------------------------------------------------------------------*
*            CHECK #1: Using simple dummy variables for policy changes [NMPP IS ALSO A DUMMY]
*---------------------------------------------------------------------------------------------*
use dataset, clear
sort countrynum quarter2
loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc mpp l.z ll.z 
loc nmpp l.nz ll.nz

**** PRELIMINARY REGRESSIONS

loc vars mincap cap cgrcap hhsc fcsc lsctot rwmol rwmolfc rwmoltot rwcons rwconsfc rwconstot rw rwfc rwtot rwcc rwtot2 gp dp dpfc dptot ///
	mpprr rrtot mrrtot fclr cgrr lr ltv ltvfc ltvtot dti dtifc dtitot elig otherfc
foreach v of var `vars' {
	gen z = 0
	replace z = 1 if d.`v'>0
	replace z = -1 if d.`v'<0
	gen nmpp = mpp1 + rest -`v'
	gen nz = 0
	replace nz = 1 if d.nmpp>0 // we also use simple dummies for the aggregate measure of non-z mpp changes 
	replace nz = -1 if d.nmpp<0
	quietly xtpmg `depvar' `ar' `controls' `basel' `mpp' `nmpp' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
	est store i`v', title (`v')
	test l.z+ll.z=0 
	estadd scalar r(p)
	drop z nz nmpp
}

**** BASELINE REGRESSION

loc vars mincap hhsc mrrtot cgrr 
foreach v of var `vars' {
	gen `v'd = 0
	replace `v'd = 1 if d.`v'>0
	replace `v'd = -1 if d.`v'<0
}
gen nmpp = mpp1 + rest - mincap - hhsc - mrrtot - cgrr  
gen nz = 0
replace nz = 1 if d.nmpp>0
replace nz = -1 if d.nmpp<0

loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc mpps l.mincapd ll.mincapd l.hhscd ll.hhscd l.mrrtotd ll.mrrtotd l.cgrrd ll.cgrrd
loc nz l.nz ll.nz

quietly xtpmg `depvar' `ar' `controls' `basel' `mpps' `nz' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store base, title (base)

**** OUTPUTTABLES
set more off
loc drop td* *nz* *con* *nhp* *pcapgdp* *rate* ec *ukr* *work*
log using robustness_simple-dummies, replace

*** preliminary regressions

** CAPITAL MEASURES
estout imincap icap icgrcap ihhsc ifcsc ilsctot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("CAPITAL MEASURES")	
** RISK WEIGHTS (separate)
estout irwmol irwmolfc irwmoltot irwcons irwconsfc irwconstot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 1")
** RISK WEIGHTS (aggregate)
estout irw irwfc irwtot irwcc irwtot2, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 2")
** PROVISIONING
estout igp idp idpfc idptot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("DYNAMIC PROVISIONING")
** LIQUIDITY MEASURES
estout impprr irrtot ilr ifclr imrrtot icgrr, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("LIQUIDITY MEASURES")
** ELIGIBILITY
estout iltv iltvfc iltvtot idti idtifc idtitot ielig, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("ELIGIBILITY MEASURES")
** other FC
estout iotherfc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("other FC")

*** baseline regression

loc drop td* *con* *ukr* 
estout base, cells(b(star fmt(2)) p(par fmt(2))) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 
log close


*---------------------------------------------------------------------------------------------*
*            Check #2: Using simple dummy variables for policy changes [NMPP IS SUM OF DUMMIES]
*---------------------------------------------------------------------------------------------*
use dataset, clear
sort countrynum quarter2
loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc mpp l.z ll.z 
loc nmpp l.nz ll.nz

**** PRELIMINARY REGRESSIONS

loc vars mincap cap cgrcap hhsc fcsc lsctot rwmol rwmolfc rwmoltot rwcons rwconsfc rwconstot rw rwfc rwtot rwcc rwtot2 gp dp dpfc dptot ///
	mpprr rrtot mrrtot fclr cgrr lr ltv ltvfc ltvtot dti dtifc dtitot elig otherfc tax other
foreach v of var `vars' {
	gen d`v' = 0
	replace d`v' = 1 if d.`v'>0
	replace d`v' = -1 if d.`v'<0
}
gen dmpp1 = dmincap + dcap + dcgrcap + dhhsc + dfcsc ///
	+ drwmol + drwmolfc + drwcons + drwconsfc + drwcc ///
	+ dgp + ddp + ddpfc ///
	+ dmpprr + drrbase + dmrrtot + dfclr + dcgrr + dlr ///
	+ dltv + dltvfc + ddti + ddtifc + dotherfc
gen drest = dtax + dother

foreach v of var `vars' {
	gen z = d`v'
	gen nz = dmpp1 + drest - d`v' // The aggregate measure of non-z mpp changes is a sum of dummies
	quietly xtpmg `depvar' `ar' `controls' `basel' `mpp' `nmpp' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
	est store i`v', title (`v')
	test l.z+ll.z=0 
	estadd scalar r(p)
	drop z nz
}

**** BASELINE REGRESSION

gen nz = dmpp1 + drest - dmincap - dhhsc - dmrrtot - dcgrr 
loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc mpps l.dmincap ll.dmincap l.dhhsc ll.dhhsc l.dmrrtot ll.dmrrtot l.dcgrr ll.dcgrr
loc nz l.nz ll.nz

quietly xtpmg `depvar' `ar' `controls' `basel' `mpps' `nz' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store base, title (base)

**** OUTPUTTABLES

set more off
loc drop td* *nz* *con* *nhp* *pcapgdp* *rate* ec *ukr* *work*
log using robustness_simple-dummies-sum, replace

*** preliminary regressions

** CAPITAL MEASURES
estout imincap icap icgrcap ihhsc ifcsc ilsctot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("CAPITAL MEASURES")	
** RISK WEIGHTS (separate)
estout irwmol irwmolfc irwmoltot irwcons irwconsfc irwconstot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 1")
** RISK WEIGHTS (aggregate)
estout irw irwfc irwtot irwcc irwtot2, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 2")
** PROVISIONING
estout igp idp idpfc idptot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("DYNAMIC PROVISIONING")
** LIQUIDITY MEASURES
estout impprr irrtot ilr ifclr imrrtot icgrr, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("LIQUIDITY MEASURES")
** ELIGIBILITY
estout iltv iltvfc iltvtot idti idtifc idtitot ielig, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("ELIGIBILITY MEASURES")
** other FC
estout iotherfc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("other FC")

*** baseline regression

loc drop td* *con* *ukr* 
estout base, cells(b(star fmt(2)) p(par fmt(2))) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 
log close



*---------------------------------------------------------------------------------------------*
*            Check #3: Adding one MPP at a time to the baseline regression
*---------------------------------------------------------------------------------------------*
use dataset, clear
sort countrynum quarter2
loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc mpps ld.mincap lld.mincap ld.mrrtot lld.mrrtot ld.cgrr lld.cgrr ld.hhsc lld.hhsc
loc mpp ld.z lld.z
loc nmpp ld.nz lld.nz

**** Baseline+  regressions

loc vars cap cgrcap fcsc rwmol rwmolfc rwmoltot rwcons rwconsfc rwconstot rw rwfc rwtot rwcc rwtot2 gp dp dpfc dptot ///
	mpprr rrtot fclr lr ltv ltvfc ltvtot dti dtifc otherfc
foreach v of var `vars' {
	gen z = `v'
	gen nz = mpp1 + rest - mincap - hhsc - mrrtot - cgrr -`v'
	quietly xtpmg `depvar' `ar' `controls' `basel' `mpps' `mpp' `nmpp' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
	est store i`v', title (`v')
	test dl.z+dll.z=0 
	estadd scalar r(p)
	drop z nz
}

**** Output tables

set more off
loc drop *td* *nz* *con* *nhp* *ec* *pcapgdp* *rate* *ukr* *work*
log using robustness_adding-1-mpp-to-baseline, replace
** capital measures
estout icap icgrcap ifcsc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("CAPITAL MEASURES")
** risk weights (separate)
estout irwmol irwmolfc irwmoltot irwcons irwconsfc irwconstot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 1")
** risk weights (aggregate)
estout irw irwfc irwtot irwcc irwtot2, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 2")
** provisioning
estout igp idp idpfc idptot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("DYNAMIC PROVISIONING")
** liquidity measures
estout impprr irrtot ilr ifclr, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("LIQUIDITY MEASURES")
** eligibility
estout iltv iltvfc iltvtot idtifc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("ELIGIBILITY MEASURES")
** other fc
estout iotherfc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("other FC")
log close



*---------------------------------------------------------------------------------------------*
*            Check #4: Adding the third lag of the core MPP variables
*---------------------------------------------------------------------------------------------*
use dataset, clear
sort countrynum quarter2
loc ar dl.lnhpi dll.lnhpi 
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc mpp dl.z dll.z dlll.z
loc nmpp dl.nz dll.nz dlll.nz

**** PRELIMINARY REGRESSIONS

loc vars mincap cap cgrcap hhsc fcsc lsctot rwmol rwmolfc rwmoltot rwcons rwconsfc rwconstot rw rwfc rwtot rwcc rwtot2 gp dp dpfc dptot ///
	mpprr rrtot mrrtot fclr cgrr lr ltv ltvfc ltvtot dti dtifc dtitot elig otherfc
foreach v of var `vars' {
	gen z = `v'
	gen nz = mpp1 + rest -`v'
	quietly xtpmg d.lnhpi `ar' `controls' `mpp' `nmpp' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
	est store i`v', title (`v')
	test dl.z+dll.z+dlll.z=0
	estadd scalar r(p)
	drop z nz
}

**** BASELINE REGRESSIONS

gen nz = mpp1 + rest - mincap - mrrtot - cgrr - hhsc

*xtpmg
loc mpps ld.mincap lld.mincap llld.mincap ld.hhsc lld.hhsc llld.hhsc ld.mrrtot lld.mrrtot llld.mrrtot ld.cgrr lld.cgrr llld.cgrr 
loc nz ld.nz lld.nz llld.nz
quietly xtpmg d.lnhpi `ar' `controls' `mpps' `nz' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store indinst, title (xtpmg1)

*xtreg
quietly xtreg d.lnhpi `ar' `controls' `mpps' `nz' td* ukr*, fe vce(robust)
est store base2, title (base2)

**** OUTPUTTABLES
set more off
loc drop td* *nz* *con* *nhp* *pcapgdp* *rate* ec *ukr* *work*
log using robustness_3lags, replace

*** preliminary regressions

** CAPITAL MEASURES
estout imincap icap icgrcap ihhsc ifcsc ilsctot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("CAPITAL MEASURES")
				
** RISK WEIGHTS (separate)
estout irwmol irwmolfc irwmoltot irwcons irwconsfc irwconstot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 1")

** RISK WEIGHTS (aggregate)
estout irw irwfc irwtot irwcc irwtot2, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 2")

** PROVISIONING
estout igp idp idpfc idptot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("DYNAMIC PROVISIONING")

** LIQUIDITY MEASURES
estout impprr irrtot ilr ifclr imrrtot icgrr, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("LIQUIDITY MEASURES")

** EILIGIBILITY
estout iltv iltvfc iltvtot idti idtifc idtitot ielig, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("ELIGIBILITY MEASURES")

** other FC
estout iotherfc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("other FC")

*** baseline regressions

loc drop td* *con* *ukr* 
estout indinst, cells(b(star fmt(2)) p(par fmt(2))) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 
estout base2, cells(b(star fmt(2)) p(par fmt(2))) stats(r2 r2_a N, fmt(3 3 0) label(R-sqr adj.R-sqr N))  ///
		drop(`drop' *td*) style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 

log close



*---------------------------------------------------------------------------------------------*
*            Check #5: Excluding the error correction term
*---------------------------------------------------------------------------------------------*
clear
use dataset
sort countrynum quarter2

**** PRELIMINARY REGRESSIONS

loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc mpp dl.z dll.z 
loc nmpp dl.nz dll.nz
loc vars mincap cap cgrcap hhsc fcsc lsctot rwmol rwmolfc rwmoltot rwcons rwconsfc rwconstot rw rwfc rwtot rwcc rwtot2 gp dp dpfc dptot ///
	mpprr rrtot mrrtot fclr cgrr lr ltv ltvfc ltvtot dti dtifc dtitot elig otherfc
foreach v of var `vars' {
	gen z = `v'
	gen nz = mpp1 + rest -`v'
	quietly xtreg d.lnhpi `ar' `controls' `mpp' `nmpp' td* ukr*, fe vce(robust)
	est store i`v', title (`v')
	test dl.z+dll.z=0
	estadd scalar r(p)
	drop z nz
}

**** BASELINE REGRESSION

gen nz = mpp1 + rest - mincap - mrrtot - cgrr - hhsc - dti
loc mpps ld.mincap lld.mincap ld.mrrtot lld.mrrtot ld.cgrr lld.cgrr ld.hhsc lld.hhsc
loc nz ld.nz lld.nz
quietly xtreg d.lnhpi `ar' `controls' `mpps' `nz' td* ukr*, fe vce(robust)
est store xtreg1, title (xtreg1)

**** OUTPUT TABLES
set more off
loc drop td* *nz* *con* *nhp* *pcapgdp* *rate* *ukr* *work* *td*
log using robustness_without-ec, replace

*** preliminary regressions

** CAPITAL MEASURES
estout imincap icap icgrcap ihhsc ifcsc ilsctot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("CAPITAL MEASURES")
				
** RISK WEIGHTS (separate)
estout irwmol irwmolfc irwmoltot irwcons irwconsfc irwconstot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 1")

** RISK WEIGHTS (aggregate)
estout irw irwfc irwtot irwcc irwtot2, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 2")

** PROVISIONING
estout igp idp idpfc idptot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("DYNAMIC PROVISIONING")

** LIQUIDITY MEASURES
estout impprr irrtot ilr ifclr imrrtot icgrr, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("LIQUIDITY MEASURES")

** ELIGIBILITY
estout iltv iltvfc iltvtot idti idtifc idtitot ielig, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("ELIGIBILITY MEASURES")

** OTHERFC
estout iotherfc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("other FC")		
	
*** baseline regression

loc drop *td* *con* *ukr* 
estout xtreg1, cells(b(star fmt(2)) p(par fmt(2))) stats(r2 r2_a N, fmt(3 3 0) label(R-sqr adj.R-sqr N)) ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 
log close



*---------------------------------------------------------------------------------------------*
*            Check #6: Exclusion of non-significant control variables
*---------------------------------------------------------------------------------------------*
clear
use dataset
sort countrynum quarter2

**** PRELIMINARY REGRESSIONS

loc ar dl.lnhpi dll.lnhpi
loc mpp dl.z dll.z 
loc nmpp dl.nz dll.nz
loc vars mincap cap cgrcap hhsc fcsc lsctot rwmol rwmolfc rwmoltot rwcons rwconsfc rwconstot rw rwfc rwtot rwcc rwtot2 gp dp dpfc dptot ///
	mpprr rrtot mrrtot fclr cgrr lr ltv ltvfc ltvtot dti dtifc dtitot elig otherfc
foreach v of var `vars' {
	gen z = `v'
	gen nz = mpp1 + rest -`v'
	quietly xtpmg d.lnhpi `ar' `mpp' `nmpp' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
	est store i`v', title (`v')
	test dl.z+dll.z=0
	estadd scalar r(p)
	drop z nz
}

**** BASELINE REGRESSION

gen nz = mpp1 + rest - mincap - hhsc - mrrtot - cgrr 

*xtpmg
loc mpps ld.mincap lld.mincap ld.hhsc lld.hhsc ld.mrrtot lld.mrrtot ld.cgrr lld.cgrr 
loc nz ld.nz lld.nz
quietly xtpmg d.lnhpi `ar' `mpps' `nz' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store indinst, title (xtpmg1)

*xtreg
quietly xtreg d.lnhpi `ar' `controls' `mpps' `nz' td* ukr*, fe vce(robust)
est store base2, title (base2)

**** OUTPUTTABLES
set more off
loc drop td* *nz* *con* *nhp* ec *ukr*
log using robustness_without-insig-controls, replace

*** preliminary regressions

** CAPITAL MEASURES
estout imincap icap icgrcap ihhsc ifcsc ilsctot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("CAPITAL MEASURES")
				
** RISK WEIGHTS (separate)
estout irwmol irwmolfc irwmoltot irwcons irwconsfc irwconstot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 1")

** RISK WEIGHTS (aggregate)
estout irw irwfc irwtot irwcc irwtot2, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("RISK WEIGHTS 2")

** DYNAMIC PROVISIONING
estout igp idp idpfc idptot, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("DYNAMIC PROVISIONING")

** LIQUIDITY MEASURES
estout impprr irrtot ilr ifclr imrrtot icgrr, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p)  legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("LIQUIDITY MEASURES")

** ELIGIBILITY
estout iltv iltvfc iltvtot idti idtifc idtitot ielig, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("ELIGIBILITY MEASURES")

** OTHERFC
estout iotherfc, cells(b(star fmt(2)) p(par fmt(2))) stats(scalar p) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("other FC")

*** baseline regression

loc drop td* *con* *ukr* 
estout indinst, cells(b(star fmt(2)) p(par fmt(2))) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 
estout base2, cells(b(star fmt(2)) p(par fmt(2))) stats(r2 r2_a N, fmt(3 3 0) label(R-sqr adj.R-sqr N)) ///
		drop(`drop' *td*) style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 
log close



*---------------------------------------------------------------------------------------------*
*            Check #7: Exclude one country at a time in the baseline
*---------------------------------------------------------------------------------------------*
clear
use dataset
sort countrynum quarter2
gen country1 = country
replace country1 = "Czech" if country=="Czech Republic"

sort countrynum quarter2
gen nz = mpp1 + rest - mincap - hhsc - mrrtot - cgrr 

**** BASELINE REGRESSIONS

loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc mpp dl.z dll.z 
loc nmpp dl.nz dll.nz

loc mpps ld.mincap lld.mincap ld.hhsc lld.hhsc ld.mrrtot lld.mrrtot ld.cgrr lld.cgrr 
loc nz ld.nz lld.nz

loc countries Albania Bulgaria Croatia Czech Estonia Hungary Latvia Lithuania Poland Romania Russia Serbia Slovakia Slovenia Turkey Ukraine
foreach c in `countries' {
	quietly xtpmg d.lnhpi `ar' `controls' `mpps' `nz' td* ukr* if country!="`c'", lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
	est store `c', title ("`c'")
	quietly xtreg d.lnhpi `ar' `controls' `mpps' `nz' td* ukr* if country!="`c'", fe vce(robust)
	est store `c'2, title ("`c'2")
}

**** OUTPUT TABLES

set more off
log using robustness_country-exclusion, replace
loc drop *td* *con* *nhp* *pcapgdp* *rate* *ukr* *work* *nz*
estout Albania Bulgaria Croatia Czech Estonia Hungary Latvia Lithuania, cells(b(star fmt(2)) p(par fmt(2))) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop' ec) style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("countries xtpmg")
estout Poland Romania Russia Serbia Slovakia Slovenia Turkey Ukraine, cells(b(star fmt(2)) p(par fmt(2))) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop' ec) style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("countries xtpmg")
estout Albania2 Bulgaria2 Croatia2 Czech2 Estonia2 Hungary2 Latvia2 Lithuania2, cells(b(star fmt(2)) p(par fmt(2))) ///
		legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("countries xtreg")
estout Poland2 Romania2 Russia2 Serbia2 Slovakia2 Slovenia2 Turkey2 Ukraine2, cells(b(star fmt(2)) p(par fmt(2))) ///
		legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) ///
		rename(LD.z "MPP t-1" L2D.z "MPP t-2") prehead("countries xtreg")
log close



*---------------------------------------------------------------------------------------------*
*            Check #8: Controlling for aggregate banking sector characteristics
*---------------------------------------------------------------------------------------------*
clear
use dataset
sort countrynum quarter2

**** BASELINE REGRESSIONS
gen nz1 = mpp1 + rest - mincap - hhsc - mrrtot - cgrr 

loc depvar d.lnhpi
loc ar dl.lnhpi dll.lnhpi
loc controls dl.lnpcapgdpsa ld.domesticrate ld.foreignrate dlnworkpop
loc level l.lnhpi l.lnpcapgdpsa
loc structure1 l.excap l.ltd l.concentration l.roa // with roa
loc structure2 l.excap l.ltd l.concentration l.roe // with roe
loc mpps1 ld.mincap lld.mincap ld.hhsc lld.hhsc ld.mrrtot lld.mrrtot ld.cgrr lld.cgrr 
loc nz1 ld.nz1 lld.nz1

quietly xtpmg `depvar' `ar' `controls' `basel' `mpps1' `nz1' `structure1' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store base1, title (base1)
quietly xtpmg `depvar' `ar' `controls' `basel' `mpps1' `nz1' `structure2' td* ukr*, lr(l.lnhpi l.lnpcapgdpsa) ec(ec) replace dfe cluster(countrynum)
est store base2, title (base2)

**** OUTPUTTABLES
set more off
loc drop td* *nz* *nhp* ec *ukr* *pcapgdp* *rate* *ukr* *work* *cons*
log using robustness_banking-system-characteristics, replace

*** baseline regressions
estout base1 base2, cells(b(star fmt(2)) p(par fmt(2))) legend label collabels(none) varlabels (_cons constant) dropped ///
		drop(`drop') style(fixed) nolegend starlevels(* 0.10 ** 0.05 *** 0.01) 
log close

